require 'fastlane/action'
require_relative '../helper/ios_cd_helper'

module Fastlane
  module Actions
    class PromoteAction < Action
      def self.run(params)

        UI.message("⌛️ Promoting to Store in external test..")

        # Decrypt the keys archive and Extract the keys archive
        Helper::IosCdHelper.decrypt_ios_keys('.')
        UI.message("👉🏼 Credentials decrypted.")

        # Retrieve credentials
        creds = Helper::IosCdHelper.parseIosCredentials('.')
        UI.message("👉🏼 Credentials parsed.")

        # Obtain App Store Connect API key
        api_key = other_action.app_store_connect_api_key(
          key_id: creds['apple_key_id'].to_s,
          issuer_id: creds['apple_issuer_id'].to_s,
          key_content: creds['apple_key_content'].to_s,
          duration: 1200,
          in_house: false
        )
        UI.message("👉🏼 API Key formated")

        # Upload build to App Store Connect using Pilot
        other_action.pilot(
          api_key: api_key,
          apple_id: creds['developer_app_id'].to_s,
          app_identifier: creds['developer_app_identifier'].to_s,
          skip_waiting_for_build_processing: false,
          distribute_only: true,
          skip_submission: true,
          distribute_external: true,
          notify_external_testers: true,
          groups: [
           "Bêta externe",
          ],
          app_platform:'ios',
        )

      end

      def self.description
        "Testflight and AppStore deployment plugin for Fastlane, simplifying the  build and deployment porcess to internal, external, and production channels, and promoting builds for testing."
      end

      def self.authors
        ["SAS Wyatt Studio"]
      end

      def self.return_value
      end

      def self.details
        "The Fastlane Testflight / Appstore deloyment action streamlines the build and deployment to internal, external and production channels. Allow you to promote builds on testflight beta tests."
      end

      def self.available_options
        []
      end

      def self.is_supported?(platform)
        [:ios].include?(platform)
      end
    end
  end
end
