require 'fastlane/action'
require 'json'
require 'fastlane_core/ui/ui'

module Fastlane
  module Helper
    class IosCdHelper
      # Check if a parameter is set or not
      def self.is_set(variable)
        str_variable = variable
        str_variable = variable.strip if variable.class.to_s == "String"
        variable && !(str_variable.nil? || str_variable.empty?)
      end

      # Decrypts ios credentials
      def self.decrypt_ios_keys(ios_directory)
        # Define the GPG command with options
        gpg_command = "gpg --quiet --batch --yes --decrypt --passphrase=#{ENV['IOS_KEYS_SECRET_PASSPHRASE']} \
          --output #{ios_directory}/ios_keys.zip #{ios_directory}/ios_keys.zip.gpg"

        # Execute the GPG command using system
        system(gpg_command)

        # Check if the command executed successfully
        if $?.success?
          # Move the extracted files to the current directory
          `jar xvf #{ios_directory}/ios_keys.zip && mv #{ios_directory}/ios_keys/* #{ios_directory}`
        else
          puts("Erreur lors de la décompression du fichier GPG")
        end
      end

      # Parse credential file
      def self.parseIosCredentials(ios_directory)
        if File.exist?("#{ios_directory}/ios_credentials.json")
          # Read file and decrypt it
          file = File.read("#{ios_directory}/ios_credentials.json")
          JSON.parse(file)

        else
          UI.error("❌ Ios credentials doesn't exist")
          puts("json file doesn't exist")
        end
      end
    end
  end
end
